summaryrefslogtreecommitdiff
path: root/source3/utils/sharesec.c
diff options
context:
space:
mode:
authorGünther Deschner <gd@samba.org>2010-05-18 03:30:40 +0200
committerGünther Deschner <gd@samba.org>2010-05-18 12:30:12 +0200
commit8951c8301ac8436d49e1641b2cc7775dda44d914 (patch)
treec85428c92ec6d4878b5628c83a57049a335b184b /source3/utils/sharesec.c
parenta8b01d1f3b4025af7e7a9d8b61deec6156737322 (diff)
downloadsamba-8951c8301ac8436d49e1641b2cc7775dda44d914.tar.gz
samba-8951c8301ac8436d49e1641b2cc7775dda44d914.tar.bz2
samba-8951c8301ac8436d49e1641b2cc7775dda44d914.zip
s3-secdesc: remove "typedef struct security_acl SEC_ACL".
Guenther
Diffstat (limited to 'source3/utils/sharesec.c')
-rw-r--r--source3/utils/sharesec.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/source3/utils/sharesec.c b/source3/utils/sharesec.c
index d4d381c95f..da8dfa28b7 100644
--- a/source3/utils/sharesec.c
+++ b/source3/utils/sharesec.c
@@ -298,7 +298,7 @@ static SEC_DESC* parse_acl_string(TALLOC_CTX *mem_ctx, const char *szACL, size_t
{
SEC_DESC *sd = NULL;
struct security_ace *ace;
- SEC_ACL *theacl;
+ struct security_acl *theacl;
int num_ace;
const char *pacl;
int i;
@@ -335,10 +335,10 @@ static SEC_DESC* parse_acl_string(TALLOC_CTX *mem_ctx, const char *szACL, size_t
return sd;
}
-/* add an ACE to a list of ACEs in a SEC_ACL */
-static bool add_ace(TALLOC_CTX *mem_ctx, SEC_ACL **the_acl, struct security_ace *ace)
+/* add an ACE to a list of ACEs in a struct security_acl */
+static bool add_ace(TALLOC_CTX *mem_ctx, struct security_acl **the_acl, struct security_ace *ace)
{
- SEC_ACL *new_ace;
+ struct security_acl *new_ace;
struct security_ace *aces;
if (! *the_acl) {
return (((*the_acl) = make_sec_acl(mem_ctx, 3, 1, ace)) != NULL);
@@ -384,7 +384,7 @@ static int ace_compare(struct security_ace *ace1, struct security_ace *ace2)
return memcmp(ace1, ace2, sizeof(struct security_ace));
}
-static void sort_acl(SEC_ACL *the_acl)
+static void sort_acl(struct security_acl *the_acl)
{
uint32 i;
if (!the_acl) return;